document.getElementById('calculateBtn').addEventListener('click', function() {
    const calculationType = document.getElementById('calculationType').value;
    let result;

    try {
        switch(calculationType) {
            case 'area':
                result = calculateRectangleArea();
                break;
            case 'cylinder_area':
                result = calculateCylinderArea();
                break;
            case 'cone_area':
                result = calculateConeArea();
                break;
            case 'trapezoid_area':
                result = calculateTrapezoidArea();
                break;
            case 'rectangle_perimeter':
                result = calculateRectanglePerimeter();
                break;
            case 'circle_perimeter':
                result = calculateCirclePerimeter();
                break;
            case 'cube_volume':
                result = calculateCubeVolume();
                break;
            case 'cylinder_volume':
                result = calculateCylinderVolume();
                break;
            case 'triangle_area':
                result = calculateTriangleArea();
                break;
            default:
                throw new Error('无效的计算类型');
        }
        showResult(result);
    } catch (error) {
        showResult(error.message, true);
    }
});

function getNumberValue(id) {
    const value = parseFloat(document.getElementById(id).value);
    if (isNaN(value)) throw new Error('请输入有效的数值');
    return value;
}

function calculateRectangleArea() {
    const length = getNumberValue('lengthInput');
    const width = getNumberValue('widthInput');
    const value = length * width;
    return {
        value: value,
        formula: '矩形面积公式：面积 = 长 × 宽',
        steps: [
            `长 = ${length}`, 
            `宽 = ${width}`,
            `面积 = ${length} × ${width} = ${value.toFixed(2)}`
        ]
    };
}

function calculateCylinderArea() {
    const radius = getNumberValue('radiusInput');
    const height = getNumberValue('heightInput');
    const value = 2 * Math.PI * radius * (radius + height);
    return {
        value: value,
        formula: '圆柱体表面积公式：2πr(r + h)',
        steps: [
            `半径 r = ${radius}`,
            `高度 h = ${height}`,
            `表面积 = 2 × π × ${radius} × (${radius} + ${height})`,
            `计算结果 = ${value.toFixed(2)}`
        ]
    };
}

function calculateConeArea() {
    const radius = getNumberValue('radiusInput');
    const generatrix = getNumberValue('generatrixInput');
    const value = Math.PI * radius * (radius + generatrix);
    return {
        value: value,
        formula: '圆锥体表面积公式：πr(r + l)',
        steps: [
            `半径 r = ${radius}`,
            `母线 l = ${generatrix}`,
            `表面积 = π × ${radius} × (${radius} + ${generatrix})`,
            `计算结果 = ${value.toFixed(2)}`
        ]
    };
}

function calculateTrapezoidArea() {
    const upper = getNumberValue('upperBaseInput');
    const lower = getNumberValue('lowerBaseInput');
    const height = getNumberValue('heightInput');
    const value = ((upper + lower) / 2) * height;
    return {
        value: value,
        formula: '梯形面积公式：(a + b)/2 × h',
        steps: [
            `上底 a = ${upper}`,
            `下底 b = ${lower}`,
            `高度 h = ${height}`,
            `面积 = (${upper} + ${lower})/2 × ${height}`,
            `计算结果 = ${value.toFixed(2)}`
        ]
    };
}

function calculateRectanglePerimeter() {
    const length = getNumberValue('lengthInput');
    const width = getNumberValue('widthInput');
    const value = 2 * (length + width);
    return {
        value: value,
        formula: '长方形周长公式：周长 = 2(长 + 宽)',
        steps: [
            `长 = ${length}`,
            `宽 = ${width}`,
            `周长 = 2 × (${length} + ${width})`,
            `计算结果 = ${value.toFixed(2)}`
        ]
    };
}

function calculateCirclePerimeter() {
    const radius = getNumberValue('radiusInput');
    const value = 2 * Math.PI * radius;
    return {
        value: value,
        formula: '圆周长公式：周长 = 2πr',
        steps: [
            `半径 r = ${radius}`,
            `周长 = 2 × π × ${radius}`,
            `计算结果 = ${value.toFixed(2)}`
        ]
    };
}

function calculateCubeVolume() {
    const length = getNumberValue('lengthInput');
    const width = getNumberValue('widthInput');
    const height = getNumberValue('heightInput');
    const value = length * width * height;
    return {
        value: value,
        formula: '立方体体积公式：体积 = 长 × 宽 × 高',
        steps: [
            `长 = ${length}`,
            `宽 = ${width}`,
            `高 = ${height}`,
            `体积 = ${length} × ${width} × ${height}`,
            `计算结果 = ${value.toFixed(2)}`
        ]
    };
}

function calculateCylinderVolume() {
    const radius = getNumberValue('radiusInput');
    const height = getNumberValue('heightInput');
    const value = Math.PI * Math.pow(radius, 2) * height;
    return {
        value: value,
        formula: '圆柱体积公式：体积 = πr²h',
        steps: [
            `半径 r = ${radius}`,
            `高度 h = ${height}`,
            `体积 = π × ${radius}² × ${height}`,
            `计算结果 = ${value.toFixed(2)}`
        ]
    };
}

function calculateTriangleArea() {
    const base = getNumberValue('baseInput');
    const height = getNumberValue('height1Input');
    const value = (base * height) / 2;
    return {
        value: value,
        formula: '三角形面积公式：面积 = 底 × 高 ÷ 2',
        steps: [
            `底 = ${base}`,
            `高 = ${height}`,
            `面积 = ${base} × ${height} ÷ 2`,
            `计算结果 = ${value.toFixed(2)}`
        ]
    };
}

function showResult(resultObj, isError = false) {
    const resultDiv = document.getElementById('geometryResult');
    resultDiv.style.color = isError ? 'red' : '#333';
    
    if (isError) {
        resultDiv.innerHTML = `<div class="error-message">错误：${resultObj}</div>`;
    } else {
        const stepsHTML = resultObj.steps.map(step => 
            `<div class="formula-step">${step}</div>`
        ).join('');
        
        resultDiv.innerHTML = `
            <div class="formula-title">${resultObj.formula}</div>
            <pre class="calculation-steps">${stepsHTML}</pre>
            <div class="final-result">计算结果：${resultObj.value.toFixed(2)}</div>
        `;
    }
}